@@ -1,11 +1,11 @@
 # Natural Language Toolkit: A Chart Parser
 #
-# Copyright (C) 2001-2021 NLTK Project
+# Copyright (C) 2001-2022 NLTK Project
 # Author: Edward Loper <edloper@gmail.com>
 #         Steven Bird <stevenbird1@gmail.com>
 #         Jean Mark Gawron <gawron@mail.sdsu.edu>
 #         Peter Ljunglöf <peter.ljunglof@heatherleaf.se>
-# URL: <http://nltk.org/>
+# URL: <https://www.nltk.org/>
 # For license information, see LICENSE.TXT
 
 """
@@ -965,7 +965,7 @@ class AbstractChartRule(ChartRuleI):
 
     - A default implementation for ``apply``.
     - A default implementation for ``apply_everywhere``,
-      (Currently, this implementation assumes that ``NUM_EDGES``<=3.)
+      (Currently, this implementation assumes that ``NUM_EDGES <= 3``.)
     - A default implementation for ``__str__``, which returns a
       name based on the rule's class name.
     """
